==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WilliamsPercentRIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { WilliamsPercentRIndicatorDescription } from "./WilliamsPercentRIndicatorDescription";
/**
 * @hidden
 */
var WilliamsPercentRIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WilliamsPercentRIndicatorDescriptionMetadata, _super);
    function WilliamsPercentRIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WilliamsPercentRIndicatorDescriptionMetadata.b = function (a) {
        if (WilliamsPercentRIndicatorDescriptionMetadata.a == null) {
            WilliamsPercentRIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WilliamsPercentRIndicatorDescriptionMetadata.c(WilliamsPercentRIndicatorDescriptionMetadata.a);
        }
        if (a.g(WilliamsPercentRIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(WilliamsPercentRIndicatorDescriptionMetadata.a);
    };
    WilliamsPercentRIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    WilliamsPercentRIndicatorDescriptionMetadata.d = function (a) {
        WilliamsPercentRIndicatorDescriptionMetadata.b(a);
        a.u("WilliamsPercentRIndicator", function () { return new WilliamsPercentRIndicatorDescription(); });
        a.t("WilliamsPercentRIndicator", WilliamsPercentRIndicatorDescriptionMetadata.a);
    };
    WilliamsPercentRIndicatorDescriptionMetadata.$t = markType(WilliamsPercentRIndicatorDescriptionMetadata, 'WilliamsPercentRIndicatorDescriptionMetadata');
    WilliamsPercentRIndicatorDescriptionMetadata.a = null;
    return WilliamsPercentRIndicatorDescriptionMetadata;
}(Base));
export { WilliamsPercentRIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WilliamsPercentRIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { WilliamsPercentRIndicatorDescription } from "./WilliamsPercentRIndicatorDescription";
/**
 * @hidden
 */
var WilliamsPercentRIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WilliamsPercentRIndicatorDescriptionMetadata, _super);
    function WilliamsPercentRIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WilliamsPercentRIndicatorDescriptionMetadata.b = function (a) {
        if (WilliamsPercentRIndicatorDescriptionMetadata.a == null) {
            WilliamsPercentRIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WilliamsPercentRIndicatorDescriptionMetadata.c(WilliamsPercentRIndicatorDescriptionMetadata.a);
        }
        if (a.j(WilliamsPercentRIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(WilliamsPercentRIndicatorDescriptionMetadata.a);
    };
    WilliamsPercentRIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    WilliamsPercentRIndicatorDescriptionMetadata.d = function (a) {
        WilliamsPercentRIndicatorDescriptionMetadata.b(a);
        a.aa("WilliamsPercentRIndicator", function () { return new WilliamsPercentRIndicatorDescription(); });
        a.z("WilliamsPercentRIndicator", WilliamsPercentRIndicatorDescriptionMetadata.a);
    };
    WilliamsPercentRIndicatorDescriptionMetadata.$t = markType(WilliamsPercentRIndicatorDescriptionMetadata, 'WilliamsPercentRIndicatorDescriptionMetadata');
    WilliamsPercentRIndicatorDescriptionMetadata.a = null;
    return WilliamsPercentRIndicatorDescriptionMetadata;
}(Base));
export { WilliamsPercentRIndicatorDescriptionMetadata };
